Feedback

Type Alias Feedback 

pub type Feedback = Result<String, String>;
Feedback provided by the interpreter. All results are either a success string or an error string. Errors will abort any nested expressions and return the error immediately.

Aliased Type

pub enum Feedback {
    Ok(String),
    Err(String),
}

Variants

1.0.0

Ok(String)

Contains the success value

1.0.0

Err(String)

Contains the error value