pub type Feedback = Result<String, String>;Expand description
Feedback provided by the interpreter. All results are either a success string or an error string. Errors will abort any nested expressions and return the error immediately.
Aliased Type
pub enum Feedback {
Ok(String),
Err(String),
}